==> haskell-cipher-aes128-0.7.0.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.4
id: cipher-aes128-0.7.0.4-DBTDbOO07KA42MaPNe3Sf
key: cipher-aes128-0.7.0.4-DBTDbOO07KA42MaPNe3Sf
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: 2c26f5d0526d1cc4d5a567e2021fce4e
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes128-0.7.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes128-0.7.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cipher-aes128-0.7.0.4
hs-libraries: HScipher-aes128-0.7.0.4-DBTDbOO07KA42MaPNe3Sf
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.4
id: cipher-aes128-0.7.0.4-C7LOlaEpY3a722fuXEDhpw
key: cipher-aes128-0.7.0.4-C7LOlaEpY3a722fuXEDhpw
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: 4412d1a8d363a60a7a86390d6d188a4d
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes128-0.7.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/cipher-aes128-0.7.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cipher-aes128-0.7.0.4
hs-libraries: HScipher-aes128-0.7.0.4-C7LOlaEpY3a722fuXEDhpw
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
